<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Gdpr Cookie Graphql by Amasty
 */

namespace Amasty\GdprCookieGraphql\Model\Resolver\Bar\Processor;

use Amasty\GdprCookie\Model\ConfigProvider;
use Amasty\GdprCookie\Model\CookiePolicy;
use Magento\Cms\Model\Template\Filter as CmsTemplateFilter;

class CommonTypeProcessor implements TypeProcessorInterface
{
    public const ACCEPT_BUTTON = 'accept';
    public const CUSTOM_BUTTON = 'custom';
    public const DECLINE_BUTTON = 'decline';

    /**
     * @var ConfigProvider
     */
    protected $configProvider;

    /**
     * @var CookiePolicy
     */
    private $cookiePolicy;

    /**
     * @var string|null
     */
    private $notificationText;

    /**
     * @var CmsTemplateFilter
     */
    private $cmsTemplateFilter;

    public function __construct(
        ConfigProvider $configProvider,
        CookiePolicy $cookiePolicy,
        CmsTemplateFilter $cmsTemplateFilter
    ) {
        $this->configProvider = $configProvider;
        $this->cookiePolicy = $cookiePolicy;
        $this->cmsTemplateFilter = $cmsTemplateFilter;
    }

    public function process(string $storeId): array
    {
        return [[
            'isCookieBarEnabled' => $this->configProvider->isCookieBarEnabled($storeId),
            'isCookiePolicyAllowed' => $this->cookiePolicy->isCookiePolicyAllowed(),
            'isDeclineEnabled' => $this->configProvider->getDeclineEnabled($storeId),
            'policyText' => $this->getNotificationText($storeId),
            'firstShowProcess' => (string)$this->configProvider->getFirstVisitShow((int)$storeId),
            'cssConfig' => $this->getCssConfig($storeId),
            'buttons' => array_values($this->getButtons($storeId))
        ]];
    }

    protected function getCssConfig(string $storeId): array
    {
        return [
            'backgroundColor' => $this->configProvider->getBackgroundColor($storeId),
            'policyTextColor' => $this->configProvider->getPolicyTextColor($storeId),
            'linksColor' => $this->configProvider->getLinksColor($storeId)
        ];
    }

    protected function getButtons(string $storeId): array
    {
        $buttons = [
            [
                'btnType' => self::ACCEPT_BUTTON,
                'btnName' => $this->configProvider->getAcceptButtonName($storeId) ? : __('Accept Cookies'),
                'btnOrder' => $this->configProvider->getAcceptButtonOrder($storeId),
                'btnColor' => $this->configProvider->getAcceptButtonColor($storeId),
                'btnColorHover' => $this->configProvider->getAcceptButtonColorHover($storeId),
                'btnTextColor' => $this->configProvider->getAcceptTextColor($storeId),
                'btnTextColorHover' => $this->configProvider->getAcceptTextColorHover($storeId)
            ],
            [
                'btnType' => self::CUSTOM_BUTTON,
                'btnName' => $this->configProvider->getSettingsButtonName($storeId) ? : __('Custom Settings'),
                'btnOrder' => $this->configProvider->getSettingsButtonOrder($storeId),
                'btnColor' => $this->configProvider->getSettingsButtonColor($storeId),
                'btnColorHover' => $this->configProvider->getSettingsButtonColorHover($storeId),
                'btnTextColor' => $this->configProvider->getSettingsTextColor($storeId),
                'btnTextColorHover' => $this->configProvider->getSettingsTextColorHover($storeId)
            ],
        ];

        if ($this->configProvider->getDeclineEnabled()) {
            $buttons[] = [
                'btnType' => self::DECLINE_BUTTON,
                'btnName' => $this->configProvider->getDeclineButtonName($storeId) ?: __('Decline Cookies'),
                'btnOrder' => $this->configProvider->getDeclineButtonOrder($storeId),
                'btnColor' => $this->configProvider->getDeclineButtonColor($storeId),
                'btnColorHover' => $this->configProvider->getDeclineButtonColorHover($storeId),
                'btnTextColor' => $this->configProvider->getDeclineTextColor($storeId),
                'btnTextColorHover' => $this->configProvider->getDeclineTextColorHover($storeId)
            ];
        }

        return $buttons;
    }

    protected function getNotificationText(string $storeId): string
    {
        if (null === $this->notificationText) {
            $this->notificationText = $this->cmsTemplateFilter->filter(
                $this->configProvider->getNotificationText($storeId)
            );
        }

        return $this->notificationText;
    }
}
